@@ -14,7 +14,7 @@ use CPAN::Audit::Version;
 use CPAN::Audit::Query;
 use CPANSA::DB;
 
-our $VERSION = '20250115.001';
+our $VERSION = '20250829.001';
 
 sub new {
 	my( $class, %params ) = @_;
@@ -220,7 +220,10 @@ sub command {
 		meta => {
 			command          => $command,
 			args             => [ @args ],
-			cpan_audit       => { version => $VERSION },
+			cpan_audit       => {
+				version => $VERSION,
+				db      => $CPANSA::DB::VERSION,
+			},
 			total_advisories => 0,
 		},
 		errors => [],
